import { __read, __decorate } from 'tslib';
import { Input, Component, NgModule } from '@angular/core';
import { set, differenceInMinutes, differenceInHours } from 'date-fns';
import { CommonModule } from '@angular/common';
import { MatTooltipModule } from '@angular/material/tooltip';

var NgxDailyGanttChartComponent = /** @class */ (function () {
    function NgxDailyGanttChartComponent() {
        this.theme = 'material';
        this.today = new Date();
        this.selectedDate = this.today;
    }
    NgxDailyGanttChartComponent.prototype.ngOnInit = function () {
        this.prepareChart();
        this.prepareTasks();
    };
    NgxDailyGanttChartComponent.prototype.prepareChart = function () {
        this.dayStartHour = this.getHourFromTime(this.dayStart);
        this.workingHours =
            this.diffFromTime(this.dayEnd, this.dayStart, 'hours') + 2;
    };
    NgxDailyGanttChartComponent.prototype.prepareTasks = function () {
        var _this = this;
        this.tasks.map(function (task) {
            task.width = _this.diffFromTime(task.end, task.start, 'minutes') * 2;
            task.offset = _this.diffFromTime(task.start, _this.dayStart, 'minutes') * 2;
            if (task.statusList) {
                task.statusList.map(function (status, index) {
                    status.offset =
                        _this.diffFromTime(status.start, _this.dayStart, 'minutes') * 2;
                    if (task.statusList[index + 1] && task.statusList[index + 1].start) {
                        status.end = task.statusList[index + 1].start;
                        status.width =
                            _this.diffFromTime(status.end, status.start, 'minutes') * 2;
                    }
                });
            }
        });
    };
    NgxDailyGanttChartComponent.prototype.onTaskClick = function (clickedTask) {
        if (clickedTask.isParent) {
            this.tasks.filter(function (task) {
                if (task.parentID === clickedTask.id) {
                    task.isHidden = !task.isHidden;
                    clickedTask.active = !clickedTask.active;
                }
            });
        }
    };
    NgxDailyGanttChartComponent.prototype.getHourFromTime = function (timeStr) {
        return Number(timeStr.split(':')[0]);
    };
    NgxDailyGanttChartComponent.prototype.getMinuteFromTime = function (timeStr) {
        return Number(timeStr.split(':')[1]);
    };
    NgxDailyGanttChartComponent.prototype.diffFromTime = function (endTime, StartTime, returnFormat) {
        var _a = __read(endTime.split(':'), 2), endTimeHour = _a[0], endTimeMinute = _a[1];
        var _b = __read(StartTime.split(':'), 2), StartTimeHour = _b[0], StartTimeMinute = _b[1];
        var taskEndDate = set(this.today, {
            hours: endTimeHour,
            minutes: endTimeMinute,
            seconds: 0
        });
        var taskStartDate = set(this.today, {
            hours: StartTimeHour,
            minutes: StartTimeMinute,
            seconds: 0
        });
        var res;
        switch (returnFormat) {
            case 'hours':
                res = differenceInHours(new Date(taskEndDate), new Date(taskStartDate));
                break;
            case 'minutes':
                res = differenceInMinutes(new Date(taskEndDate), new Date(taskStartDate));
                break;
            default:
                break;
        }
        return res;
    };
    __decorate([
        Input()
    ], NgxDailyGanttChartComponent.prototype, "dayStart", void 0);
    __decorate([
        Input()
    ], NgxDailyGanttChartComponent.prototype, "dayEnd", void 0);
    __decorate([
        Input()
    ], NgxDailyGanttChartComponent.prototype, "tasks", void 0);
    __decorate([
        Input()
    ], NgxDailyGanttChartComponent.prototype, "theme", void 0);
    NgxDailyGanttChartComponent = __decorate([
        Component({
            selector: 'gantt-chart',
            template: "<div [ngClass]=\"'theme-' + this.theme\" class=\"container mat-elevation-z8\">\r\n  <div class=\"taskTableWrapper\" #scrollOne>\r\n    <table class=\"taskTable\">\r\n      <thead>\r\n        <tr>\r\n          <th>Label</th>\r\n          <th>Start</th>\r\n          <th>End</th>\r\n          <th>Description</th>\r\n        </tr>\r\n      </thead>\r\n      <tbody>\r\n        <tr\r\n          *ngFor=\"let task of tasks\"\r\n          [ngClass]=\"{ parentTask: task.isParent, active: task.active }\"\r\n          [hidden]=\"task.isHidden\"\r\n          (click)=\"onTaskClick(task)\"\r\n        >\r\n          <td>{{ task.label }}</td>\r\n          <td>{{ task.start }}</td>\r\n          <td>{{ task.end }}</td>\r\n          <td>{{ task.description }}</td>\r\n        </tr>\r\n      </tbody>\r\n    </table>\r\n  </div>\r\n  <div\r\n    class=\"timelineWrapper\"\r\n    (scroll)=\"scrollOne.scrollTop = scrollTwo.scrollTop\"\r\n    #scrollTwo\r\n  >\r\n    <table class=\"timeline\">\r\n      <thead>\r\n        <tr>\r\n          <th *ngFor=\"let item of [].constructor(workingHours); let i = index\">\r\n            {{ this.dayStartHour + i }}:00\r\n          </th>\r\n        </tr>\r\n      </thead>\r\n      <tbody>\r\n        <div class=\"row\" *ngFor=\"let task of tasks\" [hidden]=\"task.isHidden\">\r\n          <div\r\n            class=\"taskBar\"\r\n            matTooltip=\"{{ task.tooltip }}\"\r\n            matTooltipClass=\"gantt-tooltip\"\r\n            [ngStyle]=\"{\r\n              left: task.offset + 'px',\r\n              width: task.width + 'px'\r\n            }\"\r\n          ></div>\r\n          <span\r\n            *ngFor=\"let status of task.statusList\"\r\n            class=\"statusBar\"\r\n            [ngStyle]=\"{\r\n              left: status.offset + 'px',\r\n              width: status.width + 'px',\r\n              'background-color': status.color\r\n            }\"\r\n            matTooltip=\"{{ status.tooltip }}\"\r\n            matTooltipClass=\"gantt-tooltip\"\r\n          ></span>\r\n        </div>\r\n      </tbody>\r\n    </table>\r\n  </div>\r\n</div>\r\n",
            styles: ["@charset \"UTF-8\";.theme-gradient{background:#f0c;background:linear-gradient(to right,#339,#f0c);border-radius:7px}.theme-gradient table thead>tr>th{text-align:center}.theme-gradient .taskTableWrapper{background-color:#00000029;color:#fff;border-radius:7px 0 0 7px}.theme-gradient .taskTable thead{background-color:#0000002e}.theme-gradient .taskTable tr td,.theme-gradient .taskTable tr th{height:30px}.theme-gradient .taskTable tr td{border:1px solid #ffffff12}.theme-gradient .timelineWrapper thead{background-color:#0000002e;color:#fff}.theme-gradient .timelineWrapper .row th,.theme-gradient .timelineWrapper tr th{border:1px solid #ffffff12}.theme-gradient .timelineWrapper .row .taskBar,.theme-gradient .timelineWrapper tr .taskBar{background-color:#ffffff8c;color:#fff}.theme-gradient .statusBar{background-color:#ee04c8}.theme-material{background:#fff}.theme-material thead{color:rgba(0,0,0,.54)}.theme-material .taskTableWrapper{border-right:1px solid #e0e0e0}.theme-material .taskTable table thead{color:rgba(0,0,0,.54)}.theme-material .taskTable table thead tr>th{text-align:left}.theme-material .taskTable td,.theme-material .taskTable th{border-bottom:1px solid rgba(0,0,0,.12);height:31px;font-weight:400}.theme-material .timelineWrapper .row,.theme-material .timelineWrapper tr{border-bottom:1px solid rgba(0,0,0,.12)}.theme-material .timelineWrapper .row th:not(:last-child),.theme-material .timelineWrapper tr th:not(:last-child){border-right:1px solid #e0e0e0}.theme-material .timelineWrapper .row .taskBar,.theme-material .timelineWrapper tr .taskBar{background-color:#d8d8d8}.theme-material .statusBar{background-color:#ee04c8}::-webkit-scrollbar{width:6px;height:6px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888}::-webkit-scrollbar-thumb:hover{background:#555}.container{height:400px;font-family:Calibri,sans-serif;font-size:12px;margin:40px;padding:20px}table td,table th{line-height:20px}.taskTableWrapper{height:100%;overflow:scroll hidden;display:inline-block;width:calc(30% - 2px)}.taskTable{width:100%;border-collapse:collapse}.taskTable tr{white-space:nowrap}.taskTable tr td,.taskTable tr th{text-align:left;padding:5px;box-sizing:border-box;height:30px}.timelineWrapper{height:100%;overflow:scroll auto;display:inline-block;width:70%}.timeline{border-collapse:collapse}.timeline .row,.timeline tr{white-space:nowrap;position:relative;height:30px}.timeline .row th,.timeline tr th{display:inline-block;box-sizing:border-box;width:120px;height:31px;padding:5px}.timeline .row .taskBar,.timeline tr .taskBar{display:inline-block;box-sizing:border-box;margin:4px 0;height:22px;text-align:center;padding:5px;border-radius:7px;position:relative;line-height:13px}.timeline .row .statusBar,.timeline tr .statusBar{position:absolute;height:16px;width:20px;top:3px;box-sizing:border-box;margin:4px 0}.timeline .row span:first-of-type,.timeline tr span:first-of-type{border-radius:7px 0 0 7px}.timeline .row span:last-of-type,.timeline tr span:last-of-type{border-radius:0 7px 7px 0}.parentTask{cursor:pointer}.parentTask.active>td:first-child::before{content:\"\u25BC \"}.parentTask>td:first-child::before{content:\"\u25B6 \"}.parentTask+tr td:first-child{padding-left:25px!important}::ng-deep .gantt-tooltip{white-space:pre-line}"]
        })
    ], NgxDailyGanttChartComponent);
    return NgxDailyGanttChartComponent;
}());

var NgxDailyGanttChartModule = /** @class */ (function () {
    function NgxDailyGanttChartModule() {
    }
    NgxDailyGanttChartModule = __decorate([
        NgModule({
            declarations: [NgxDailyGanttChartComponent],
            imports: [CommonModule, MatTooltipModule],
            exports: [NgxDailyGanttChartComponent]
        })
    ], NgxDailyGanttChartModule);
    return NgxDailyGanttChartModule;
}());

/*
 * Public API Surface of ngx-daily-gantt-chart
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxDailyGanttChartComponent, NgxDailyGanttChartModule };
//# sourceMappingURL=ngx-daily-gantt-chart.js.map
